DeviceAttr

Struct DeviceAttr 

pub struct DeviceAttr {
    pub attr: ibv_device_attr_ex,
}
The attributes of an RDMA device that is associated with a context.

Fields

attr: ibv_device_attr_ex

Implementations

Source

impl DeviceAttr

pub fn phys_port_cnt(&self) -> u8

Get the number of physical ports on this device.

pub fn completion_timestamp_mask(&self) -> u64

Get the completion timestamp mask on this device, 0 for unsupported of hardware completion timestamp.

pub fn vendor_id(&self) -> u32

Get the IEEE device’s vendor.

pub fn vendor_part_id(&self) -> u32

Get the device’s Part ID, as supplied by the vendor.

pub fn firmware_version(&self) -> String

Get the firmware version of the RDMA device, it would be empty string if no version filled.

pub fn hardware_version(&self) -> u32

Get the hardware version of the RDMA device, as supplied by the vendor.

pub fn sys_image_guid(&self) -> Guid

Get the Guid associated with this RDMA device and other devices which are part of a single system.