DeviceContext

Struct DeviceContext 

pub struct DeviceContext { /* private fields */ }
A context of the RDMA device, could be used to query its resources or creating PD or CQ.

Implementations

Source

impl DeviceContext

pub fn alloc_pd( self: &Arc<Self>, ) -> Result<Arc<ProtectionDomain>, AllocateProtectionDomainError>

Allocate a protection domain.

pub fn create_comp_channel( self: &Arc<Self>, ) -> Result<Arc<CompletionChannel>, CreateCompletionChannelError>

Create a completion event channel.

pub fn create_cq_builder(self: &Arc<Self>) -> CompletionQueueBuilder

Create a factory for creating BasicCompletionQueue and ExtendedCompletionQueue.

pub fn query_device(&self) -> Result<DeviceAttr, QueryDeviceError>

Query the attributes of the RDMA device.

pub fn query_port(&self, port_num: u8) -> Result<PortAttr, QueryPortError>

Query the attributes of a physical port.

pub fn query_gid( &self, port_num: u8, gid_index: u32, ) -> Result<Gid, QueryGidError>

Query the Gid of the GID specified by GID index and port number.

pub fn query_gid_ex( &self, port_num: u8, gid_index: u32, ) -> Result<GidEntry, QueryGidError>

Query the GidEntry of the GID specified by GID index and port number.

pub fn query_gid_type( &self, port_num: u8, gid_index: u32, ) -> Result<u32, QueryGidError>

Query the type of the GID specified by GID index and port number. Note that this gid type is represented by u32:

pub fn query_gid_table(&self) -> Result<Vec<GidEntry>, QueryGidTableError>

Query all GidEntrys on a RDMA device.

pub unsafe fn context(&self) -> NonNull<ibv_context>

Safety

Return the handle of device context. We mark this method unsafe because the lifetime of ibv_context is not associated with the return value.