PortAttr

Struct PortAttr 

pub struct PortAttr { /* private fields */ }
The attributes of a port of an RDMA device context.

Implementations

Source

impl PortAttr

pub fn max_mtu(&self) -> Mtu

Get the maximum MTU supported by this port.

pub fn active_mtu(&self) -> Mtu

Get the maximum MTU enabled on this port to transmit and receive.

pub fn gid_tbl_len(&self) -> i32

Get the length of GID table of this port.

Get the link layer protocol used by this port.

pub fn port_state(&self) -> PortState

Get the logical port status of this port.

pub fn phys_state(&self) -> PhysicalState

Get the physical link status of this port.

pub fn active_width(&self) -> PortWidth

Get the active link width of this port.

pub fn active_speed(&self) -> PortSpeed

Get the active link speed of this port.