pub struct DeviceAttr {
pub attr: ibv_device_attr_ex,
}Expand description
The attributes of an RDMA device that is associated with a context.
Fields
attr: ibv_device_attr_exImplementations
Sourceimpl DeviceAttr
impl DeviceAttr
Sourcepub fn phys_port_cnt(&self) -> u8
pub fn phys_port_cnt(&self) -> u8
Get the number of physical ports on this device.
Sourcepub fn completion_timestamp_mask(&self) -> u64
pub fn completion_timestamp_mask(&self) -> u64
Get the completion timestamp mask on this device, 0 for unsupported of hardware completion
timestamp.
Sourcepub fn vendor_part_id(&self) -> u32
pub fn vendor_part_id(&self) -> u32
Get the device’s Part ID, as supplied by the vendor.
Sourcepub fn firmware_version(&self) -> String
pub fn firmware_version(&self) -> String
Get the firmware version of the RDMA device, it would be empty string if no version filled.
Sourcepub fn hardware_version(&self) -> u32
pub fn hardware_version(&self) -> u32
Get the hardware version of the RDMA device, as supplied by the vendor.
Sourcepub fn sys_image_guid(&self) -> Guid
pub fn sys_image_guid(&self) -> Guid
Get the Guid associated with this RDMA device and other devices which are part of a
single system.