pub struct PortAttr { /* private fields */ }Expand description
The attributes of a port of an RDMA device context.
Implementations
Sourceimpl PortAttr
impl PortAttr
Sourcepub fn active_mtu(&self) -> Mtu
pub fn active_mtu(&self) -> Mtu
Get the maximum MTU enabled on this port to transmit and receive.
Sourcepub fn gid_tbl_len(&self) -> i32
pub fn gid_tbl_len(&self) -> i32
Get the length of GID table of this port.
Sourcepub fn link_layer(&self) -> LinkLayer
pub fn link_layer(&self) -> LinkLayer
Get the link layer protocol used by this port.
Sourcepub fn port_state(&self) -> PortState
pub fn port_state(&self) -> PortState
Get the logical port status of this port.
Sourcepub fn phys_state(&self) -> PhysicalState
pub fn phys_state(&self) -> PhysicalState
Get the physical link status of this port.
Sourcepub fn active_width(&self) -> PortWidth
pub fn active_width(&self) -> PortWidth
Get the active link width of this port.
Sourcepub fn active_speed(&self) -> PortSpeed
pub fn active_speed(&self) -> PortSpeed
Get the active link speed of this port.